"""This file tests the overlap of events with the queried span.

It might be that events overlap the start and end of the time span.
This must test
- single events overlapping
- recurrent events overlapping
both
- start
- end
with both
- datetime
- date
"""

def test_implement_tests(todo):
    pass
